@@ -20,6 +20,7 @@ import os,datetime,stat,logging,sets,random
 from noc.sa.models import Activator,AdministrativeDomain,ObjectGroup,ManagedObject
 from noc.main.menu import Menu
 from noc.sa.protocols.sae_pb2 import *
+from noc.main.search import SearchResult
 
 profile_registry.register_all()
 vcs_registry.register_all()
@@ -65,7 +66,7 @@ class Object(models.Model):
     vcs=property(_vcs)
         
     def save(self,*args,**kwargs):
-        if not in_dir(self.path,self.repo):
+        if self.repo_path and not in_dir(self.path,self.repo):
             raise Exception("Attempting to write outside of repo")
         mv=None
         if self._get_pk_val():
@@ -197,6 +198,31 @@ class Object(models.Model):
         if user.is_superuser:
             return True
         return False
+    ##
+    ## Search engine
+    ##
+    @classmethod
+    def search(cls,user,query,limit):
+        for o in [o for o in cls.objects.all() if o.repo_path and o.has_access(user)]:
+            data=o.data
+            if query in o.repo_path: # If repo_path matches
+                yield SearchResult(
+                    url="/cm/view/%s/%d/"%(o.repo_name,o.id),
+                    title="CM: "+unicode(o),
+                    text=unicode(o),
+                    relevancy=1.0, # No weighted search yes
+                    )                
+            elif data and query in data: # Dumb substring search in config
+                idx=data.index(query)
+                idx_s=max(0,idx-100)
+                idx_e=min(len(data),idx+len(query)+100)
+                text=data[idx_s:idx_e]
+                yield SearchResult(
+                    url="/cm/view/%s/%d/"%(o.repo_name,o.id),
+                    title="CM: "+unicode(o),
+                    text=text,
+                    relevancy=1.0, # No weighted search yes
+                    )
 ##
 ## Config
 ##
@@ -215,12 +241,13 @@ class Config(Object):
         def pull_callback(result=None,error=None):
             if error:
                 if error.code==ERR_OVERLOAD:
-                    timeout=150
+                    timeout=config.getint("cm","timeout_overload")
                 elif error.code==ERR_DOWN:
-                    timeout=60
+                    timeout=config.getint("cm","timeout_down")
                 else:
-                    timeout=300
-                timeout+=random.randint(-timeout/10,timeout/10) # Add jitter to avoid blocking by dead task
+                    timeout=config.getint("cm","timeout_error")
+                variation=config.getint("cm","timeout_variation")
+                timeout+=random.randint(-timeout/variation,timeout/variation) # Add jitter to avoid blocking by dead task
                 self.next_pull=datetime.datetime.now()+datetime.timedelta(seconds=timeout)
                 self.save()
                 return            
