@@ -150,7 +150,9 @@ def close_event(request,event_id):
 @permission_required("fm.add_eventclassificationrule")
 def create_rule(request,event_id):
     def re_q(s):
-        return s.replace("\\","\\\\").replace(".","\\.").replace("+","\\+").replace("*","\\*")
+        for qc in ["\\",".","+","*","[","]","(",")"]:
+            s=s.replace(qc,"\\"+qc)
+        return s
     event=get_object_or_404(Event,id=int(event_id))
     rule=EventClassificationRule(event_class=event.event_class,name="Rule #%d:%d"%(event.id,random.randint(0,100000)),preference=1000)
     rule.save()
