@@ -9,7 +9,7 @@
 """
 from django.conf.urls.defaults import *
 from django.contrib.auth.decorators import login_required
-from noc.main.views import index,logout,report,report_index,success,failure,menu,search
+from noc.main.views import index,logout,report,report_index,success,failure,menu,search,config_index,config_view
 
 urlpatterns = patterns ( None,
         (r"^$",        login_required(index)),
@@ -20,4 +20,6 @@ urlpatterns = patterns ( None,
         (r"failure/$", login_required(failure)),
         (r"menu/$",    login_required(menu)),
         (r"search/$",  login_required(search)),
+        (r"config/$",  login_required(config_index)),
+        (r"config/(?P<config>.+)/$",  login_required(config_view)),
 )
